SerializerConfig

Struct SerializerConfig 

pub struct SerializerConfig { /* private fields */ }
Configures how values are serialized to TOML.

The value has to serialize to a map (for instance a struct or a map type) as TOML documents are tables. As TOML has no null value, map entries with null values (such as None) are skipped, null values in sequences are an error.

Values that are maps are written as [table] sections and sequences of maps as [[array]] sections unless they are nested in other sequences or have the Layout::Compact hint (see hints) which makes them inline. Inline tables and inline arrays of tables have that hint when deserialized, so they stay inline when a value is deserialized and serialized again. The output is compatible with TOML 1.0.

to_string works like the to_string function.

Implementations

Source

impl SerializerConfig

pub const fn new() -> SerializerConfig

Creates the default configuration.

pub const fn builder() -> SerializerConfigBuilder

Returns a builder for the configuration (see SerializerConfigBuilder).

pub const fn into_builder(self) -> SerializerConfigBuilder

Returns a builder that starts with this configuration.

pub fn set_context(&mut self, context: Context)

Sets the context the values are serialized in.

The values of the context are the defaults of the extension values of the state (see Context), for instance the BytesFormat. The serializers and writers created with the configuration use this context. A context set on the driver takes precedence.

pub fn context(&self) -> &Context

Returns the context the values are serialized in.

pub fn to_string<T: Serialize + ?Sized>( &self, value: &T, ) -> Result<String, Error>

Serializes the given value.

pub fn to_string_with<F, T: Serialize + ?Sized>( &self, value: &T, setup: F, ) -> Result<String, Error>
where F: FnOnce(&mut SerializeDriver<'_>),

Serializes the given value with a configured driver.

The callback is invoked with the driver before the serialization starts, for instance to add Layers.

Source

impl SerializerConfig

pub fn writer<W: Write>(&self, writer: W) -> Writer<W, Serializer>

Creates a writer of a TOML document (see deser::io::Writer).

A stream holds a single document, writing a second value fails. The document is written with a single write once it’s complete.

pub fn to_writer<W: Write, T: Serialize + ?Sized>( &self, writer: W, value: &T, ) -> Result<(), Error>

Serializes a value to a writer.

See to_writer.